.. image:: https://s6.uupload.ir/files/download_9zh5.png

|pypi| |pyversion| |downloads|

.. |pypi| image:: https://img.shields.io/pypi/v/solar_functions.svg
   :alt: solar_functions PyPI Project Page
   :target: https://pypi.org/project/solar_functions/

.. |pyversion| image:: https://img.shields.io/pypi/pyversions/solar_functions.svg
   :alt: Supported Python Versions

.. |downloads| image:: https://static.pepy.tech/badge/solar_functions/month
   :alt: PyPI Download Count
   :target: https://pepy.tech/project/solar_functions

.. badges-end



**Install Module**

::

    $ pip3 install solar_functions



**Solar Functions**

- Get The Exact **Solar Date**,

- Get The Exact **Solar Time**,

- **High Speed** in Receiving **Date** And **Time**,



**Get Solar Date**

::

    from solar_functions import solar

    print(solar.date)



**Get Solar Time**

::

    from solar_functions import solar

    print(solar.time)




**Description**

This **Module** is Designed For **Iranian developers** And **programmers** By **Sami Dev** so That They Can Easily Get The **Date** And **Solar Time**, Hopefully With This Coding Module it Will Be Easy For **Iranian Developers** And **Programmers**.



**Thank You For Your Support, Sami Dev**